@@ -42,26 +42,28 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_lambda
-import aws_cdk.core
+import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_5443dbc3
+import aws_cdk.core as _aws_cdk_core_f4b25747
 
 
 class CurlLayer(
-    aws_cdk.aws_lambda.LayerVersion,
+    _aws_cdk_aws_lambda_5443dbc3.LayerVersion,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-lambda-layer-curl.CurlLayer",
 ):
     '''An AWS Lambda layer that includes the curl.'''
 
-    def __init__(self, scope: aws_cdk.core.Construct, id: builtins.str) -> None:
+    def __init__(
+        self,
+        scope: _aws_cdk_core_f4b25747.Construct,
+        id: builtins.str,
+    ) -> None:
         '''
         :param scope: -
         :param id: -
         '''
         if __debug__:
-            def stub(scope: aws_cdk.core.Construct, id: builtins.str) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__8b6ac3f7b211cb260c976aa26ddff6970c25c928d63a470c513c0179ac044aad)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         jsii.create(self.__class__, self, [scope, id])
@@ -72,3 +74,10 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__8b6ac3f7b211cb260c976aa26ddff6970c25c928d63a470c513c0179ac044aad(
+    scope: _aws_cdk_core_f4b25747.Construct,
+    id: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
